==> silly-collections-4.9.0-sources.jar: de/alpharogroup/comparators/ComparableComparator.java <==
/**
 * The MIT License
 *
 * Copyright (C) 2007 Asterios Raptis
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of this software and associated documentation files (the
 * "Software"), to deal in the Software without restriction, including
 * without limitation the rights to use, copy, modify, merge, publish,
 * distribute, sublicense, and/or sell copies of the Software, and to
 * permit persons to whom the Software is furnished to do so, subject to
 * the following conditions:
 *
 * The above copyright notice and this permission notice shall be
 * included in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
 * LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
 * OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
 * WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */
package de.alpharogroup.comparators;

import java.io.Serializable;
import java.util.Comparator;

/**
 * The Class ComparableComparator.
 *
 * @param <T>
 *            the generic type of the comparing object
 */
public class ComparableComparator<T extends Comparable<T>> implements Comparator<T>, Serializable
{

	/**
	 * The serialVersionUID.
	 */
	private static final long serialVersionUID = 1L;

	/** The sort order. Default is ascending. */
	private SortOrder sortOrder = SortOrder.ASCENDING;

	/**
	 * Instantiates a new comparable comparator.
	 */
	public ComparableComparator()
	{
	}

	/**
	 * Instantiates a new comparable comparator.
	 *
	 * @param sortOrder
	 *            the sort order
	 */
	public ComparableComparator(final SortOrder sortOrder)
	{
		this.sortOrder = sortOrder;
	}

	/**
	 * {@inheritDoc}
	 */
	@Override
	public int compare(final T object, final T compareWithObject)
	{
		return ComparatorExtensions.compare(object, compareWithObject, sortOrder);
	}

}

==> silly-collections-4.17.0-sources.jar: de/alpharogroup/comparators/ComparableComparator.java <==
/**
 * The MIT License
 *
 * Copyright (C) 2015 Asterios Raptis
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of this software and associated documentation files (the
 * "Software"), to deal in the Software without restriction, including
 * without limitation the rights to use, copy, modify, merge, publish,
 * distribute, sublicense, and/or sell copies of the Software, and to
 * permit persons to whom the Software is furnished to do so, subject to
 * the following conditions:
 *
 * The above copyright notice and this permission notice shall be
 * included in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
 * LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
 * OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
 * WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */
package de.alpharogroup.comparators;

import java.io.Serializable;
import java.util.Comparator;

/**
 * The class ComparableComparator.
 *
 * @param <T>
 *            the generic type of the comparing object
 */
public class ComparableComparator<T extends Comparable<T>> implements Comparator<T>, Serializable
{

	/**
	 * The serialVersionUID.
	 */
	private static final long serialVersionUID = 1L;

	/** The sort order. Default is ascending. */
	private SortOrder sortOrder = SortOrder.ASCENDING;

	/**
	 * Instantiates a new comparable comparator.
	 */
	public ComparableComparator()
	{
	}

	/**
	 * Instantiates a new comparable comparator.
	 *
	 * @param sortOrder
	 *            the sort order
	 */
	public ComparableComparator(final SortOrder sortOrder)
	{
		this.sortOrder = sortOrder;
	}

	/**
	 * {@inheritDoc}
	 */
	@Override
	public int compare(final T object, final T compareWithObject)
	{
		return ComparatorExtensions.compare(object, compareWithObject, sortOrder);
	}

}
